@@ -2,13 +2,13 @@ package LCFG::Build::PkgSpec; # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: PkgSpec.pm.in 20799 2012-04-30 13:47:10Z squinney@INF.ED.AC.UK $
+# $Id: PkgSpec.pm.in 27862 2015-06-24 10:11:40Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-PkgSpec/lib/LCFG/Build/PkgSpec.pm.in,v $
-# $Revision: 20799 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-PkgSpec/LCFG_Build_PkgSpec_0_0_36/lib/LCFG/Build/PkgSpec.pm.in $
-# $Date: 2012-04-30 14:47:10 +0100 (Mon, 30 Apr 2012) $
+# $Revision: 27862 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-PkgSpec/LCFG_Build_PkgSpec_0_1_0/lib/LCFG/Build/PkgSpec.pm.in $
+# $Date: 2015-06-24 11:11:40 +0100 (Wed, 24 Jun 2015) $
 
-our $VERSION = '0.0.36';
+our $VERSION = '0.1.0';
 
 use Data::Structure::Util ();
 use DateTime ();
@@ -151,6 +151,23 @@ has 'orgident' => (
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
+sub perl_version {
+    my ($self) = @_;
+
+    my $perl_version = $self->version;
+    if ( $perl_version =~ s/_dev$// ) {
+
+        # Cannot use a non-numeric in a Perl version string. A "devel"
+        # version is signified with a suffix which is an underscore
+        # and a release number. See "perldoc version" for details.
+
+        my $release = $self->release;
+        $perl_version .= q{_} . $release;
+    }
+
+    return $perl_version;
+}
+
 sub get_major {
     my ($self) = @_;
 
@@ -478,7 +495,7 @@ LCFG::Build::PkgSpec - Object-oriented interface to LCFG build metadata
 
 =head1 VERSION
 
-This documentation refers to LCFG::Build::PkgSpec version 0.0.36
+This documentation refers to LCFG::Build::PkgSpec version 0.1.0
 
 =head1 SYNOPSIS
 
@@ -649,6 +666,13 @@ Save the object data into the LCFG metadata file.
 Create from the old-style LCFG config.mk a new object which represents
 the LCFG build metadata.
 
+=item perl_version
+
+This returns the package version as a string in a style which is safe
+for use in Perl modules. If this is a development release the C<dev>
+suffix is replaced with the value of the release. This is done because
+Perl versions are not permitted to contain non-numeric characters.
+
 =item get_major
 
 Get just the major (first) part of the package version.
@@ -783,7 +807,7 @@ Stephen Quinney <squinney@inf.ed.ac.uk>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2008-2009 University of Edinburgh. All rights reserved.
+Copyright (C) 2008-2015 University of Edinburgh. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the terms of the GPL, version 2 or later.
